@@ -1,4 +1,4 @@
-/* $Id: bogoutil.c 6820 2009-02-22 20:13:08Z relson $ */
+/* $Id: bogoutil.c 6920 2010-07-05 20:05:57Z relson $ */
 
 /*****************************************************************************
 
@@ -312,7 +312,7 @@ static ex_t display_words(bfpath *bfp, int argc, char **argv, bool show_probabil
 {
     byte buf[BUFSIZE];
     buff_t *buff = buff_new(buf, 0, BUFSIZE);
-    const byte *word = buf;
+    const byte *word;
 
     const char *path = bfp->filepath;
 
@@ -460,7 +460,7 @@ static void print_version(void)
     (void)fprintf(stdout,
 		  "%s version %s\n"
 		  "    Database: %s\n"
-		  "Copyright (C) 2002-2009 David Relson, Matthias Andree\n"
+		  "Copyright (C) 2002-2010 David Relson, Matthias Andree\n"
 		  "Copyright (C) 2002-2003 Gyepi Sam.\n\n"
 		  "%s comes with ABSOLUTELY NO WARRANTY.  "
 		  "This is free software, and\nyou are welcome to "
